@@ -696,3 +696,40 @@ class TestDebuggingBreakpoints(object):
         assert "1 failed" in rest
         assert "reading from stdin while output" not in rest
         TestPDB.flush(child)
+
+
+class TestTraceOption:
+    def test_trace_sets_breakpoint(self, testdir):
+        p1 = testdir.makepyfile(
+            """
+            def test_1():
+                assert True
+            """
+        )
+        child = testdir.spawn_pytest("--trace " + str(p1))
+        child.expect("test_1")
+        child.expect("(Pdb)")
+        child.sendeof()
+        rest = child.read().decode("utf8")
+        assert "1 passed" in rest
+        assert "reading from stdin while output" not in rest
+        TestPDB.flush(child)
+
+    def test_trace_against_yield_test(self, testdir):
+        p1 = testdir.makepyfile(
+            """
+            def is_equal(a, b):
+                assert a == b
+
+            def test_1():
+                yield is_equal, 1, 1
+            """
+        )
+        child = testdir.spawn_pytest("--trace " + str(p1))
+        child.expect("is_equal")
+        child.expect("(Pdb)")
+        child.sendeof()
+        rest = child.read().decode("utf8")
+        assert "1 passed" in rest
+        assert "reading from stdin while output" not in rest
+        TestPDB.flush(child)
